import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;

public class RadnaOrganizacija {
	private Radnik[] radnici;
	
	public RadnaOrganizacija(String spisakRadnika) 
		throws IOException
	{
		BufferedReader br = new BufferedReader(new FileReader(spisakRadnika));
		
		int brRadnika = Integer.parseInt(br.readLine());
		radnici = new Radnik[brRadnika];
		
		for (int i = 0; i < brRadnika; i++) {
			String[] tokeni = br.readLine().split(",");
			
			String id = tokeni[0].trim();
			int radniStaz = Integer.parseInt(tokeni[1].trim());
			double plata = Double.parseDouble(tokeni[2].trim());
			
			if (tokeni.length == 4) {
				String idNadredjeni = tokeni[3].trim();
				Radnik nadredjeni = pronadjiNadredjenog(idNadredjeni, i);
				if (nadredjeni == null) {
					br.close();
					throw new IOException("Greska u ulaznom fajlu");
				}
				
				radnici[i] = new Radnik(id, radniStaz, plata, nadredjeni);
			} else {
				radnici[i] = new Direktor(id, radniStaz, plata);
			}
		}
		
		br.close();
	}
	
	private Radnik pronadjiNadredjenog(String idNadr, int brojDodatihRadnika) {
		for (int i = 0; i < brojDodatihRadnika; i++) {
			if (radnici[i].getId().compareTo(idNadr) == 0) {
				return radnici[i];
			}
		}
		
		return null;
	}
	
	public void stampajSveRadnike() {
		for (int i = 0; i < radnici.length; i++) {
			System.out.println(radnici[i]);
		}
	}
	
	public void plataNadredjenogManja() {
		for (int i = 0; i < radnici.length; i++) {
			Radnik r = radnici[i];
			if (!(r instanceof Direktor)) {
				Radnik nadr = r.getNadredjeni();
				if (nadr.getPlata() < r.getPlata()) {
					System.out.println(
						r.getId() + " ima platu " + r.getPlata() + 
						", a njegov nadredjeni " + nadr.getId() + 
						" ima platu " + nadr.getPlata()
					);
				}
			}
		}
	}
	
	public void stampajSveNadredjene(String id) {
		Radnik r = null;
		for (int i = 0; i < radnici.length; i++) {
			if (radnici[i].getId().compareTo(id) == 0) {
				r = radnici[i];
				break;
			}
		}
		
		if (r == null) {
			System.out.println("Radnik " + id + " ne postoji");
		} else if (r instanceof Direktor) {
			System.out.println("Radnik " + id + " je direktor");
		} else {
			System.out.println("Nadredjeni radnici za " + id + " su: ");
			
			Radnik nadr = r.getNadredjeni();
			while (nadr != null) {
				System.out.println(nadr.getId());
				nadr = nadr.getNadredjeni();
			}
		}
	}
	
	public static void main(String[] args) 
		throws IOException
	{
		RadnaOrganizacija ro = new RadnaOrganizacija("SpisakRadnika.txt");
		ro.stampajSveNadredjene("Sale");
		ro.plataNadredjenogManja();
	}
	
}
